@@ -1,7 +1,24 @@
+#' @method table_results mixture_list
+#' @export
+table_results.mixture_list <- function (x, columns = c("label", "est_sig", "se", "pval", "confint", "group", "class", "level"), digits = 2, format_numeric = TRUE, ...)
+{
+  cl <- match.call()
+  out <- suppressWarnings(lapply(x, function(thismod){
+    cl[[1L]] <- quote(table_results)
+    cl[["x"]] <- thismod
+    tmp <- eval.parent(cl)
+    tmp$model <- thismod$name
+    if(!"class" %in% names(tmp) & thismod$name == "mix1"){
+      tmp$class <- "class1"
+    }
+    tmp
+  }))
+  bind_list(out)
+}
 #' @method table_results MxModel
 #' @export
 #' @importFrom stats pnorm
-table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pval", "confint", "group", "class", "level"), digits = 2, ...)
+table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pval", "confint", "group", "class", "level"), digits = 2, format_numeric = TRUE, ...)
 {
   # Multigroup:
   # attr(attr(fit,"runstate")$fitfunctions$mg.fitfunction, "groups")
@@ -21,8 +38,6 @@ table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pva
         results_std[[n]]$matrix <- paste(n, results_std[[n]]$matrix, sep = ".")
       }
       results_std <- bind_list(results_std)
-      renamez <- c("Raw.Value" = "Estimate", "Raw.SE" = "Std.Error", "Std.Value" = "std_est", "Std.SE" = "std_se", "label" = "openmx_label")
-      names(results_std)[match(names(renamez), names(results_std))] <- renamez[names(renamez) %in% names(results_std)]
     }
     # Remove redundant correlations
     remove_these <- results_std$name[endsWith(results_std$matrix, ".S")]
@@ -34,6 +49,13 @@ table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pva
       flip_S$name <- gsub("\\[(\\d+),(\\d+)\\]$", "\\[\\2,\\1\\]", flip_S$name)
       results_std[these_rows, ] <- flip_S[, names(results_std)]
     }
+    # Rename columns
+    renamez <- c("Raw.Value" = "Estimate", "Raw.SE" = "Std.Error", "Std.Value" = "std_est", "Std.SE" = "std_se", "label" = "openmx_label")
+    names(results_std)[match(names(renamez), names(results_std))] <- renamez[names(renamez) %in% names(results_std)]
+
+    # Compute p-value and CI
+    results_std$pval_std <- 2*pnorm(abs(results_std$std_est)/results_std$std_se, lower.tail = FALSE)
+    results_std$confint_std <- conf_int(results_std$std_est, se = results_std$std_se)
     # Clean up name vs label
     tab <- merge(results, results_std, by = "name", all = TRUE)
     results <- two_to_one(tab)
@@ -88,8 +110,8 @@ table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pva
       results$confint[match(ci_x$name, results$name)] <- ci_x$CI
     }
   }
-  results$pvalue <- 2*pnorm(abs(results$Estimate)/results$Std.Error, lower.tail = FALSE)
-  results$est_sig <- est_sig(results$est, sig = results$pvalue)
+  results$pval <- 2*pnorm(abs(results$Estimate)/results$Std.Error, lower.tail = FALSE)
+  results$est_sig <- est_sig(results$est, sig = results$pval)
   results[c("estimate", "Estimate")] <- NULL
   miscols <- colSums(is.na(results)) == nrow(results)
   if(any(miscols)) results <- results[, !miscols, drop = FALSE]
@@ -100,6 +122,21 @@ table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pva
   # Drop internal stuff
   internalstuff <- grepl("mat_dev", results$name)
   if(any(internalstuff)) results <- results[!internalstuff, ]
+  # Make uniform column names
+  renam <- c(std.value = "est_std", std.se = "se_std")
+  if(any(names(renam) %in% names(results))) names(results)[match(names(renam), names(results))] <- renam
+  # Impose similar order to lavaan
+  firstcols <- c("lhs", "op", "rhs", "est", "se", "pval", "confint", "est_sig",
+    "est_std", "se_std", "pval_std", "confint_std", "est_sig_std",
+    "label")
+  results <- results[, c(firstcols[firstcols %in% names(results)], names(results)[!names(results) %in% firstcols]), drop = FALSE]
+  # Format using digits
+  value_columns <- names(results)[can_be_numeric(results)]
+  if(format_numeric){
+    results[, value_columns] <- lapply(results[, value_columns],
+                                       format_with_na, digits = digits, format = "f")
+  }
+
   if(!is.null(columns)) {
     results <- results[, na.omit(match(columns, names(results))), drop = FALSE]
   }
@@ -180,10 +217,14 @@ from_submodels <- function(x, what = NULL, ...){
     thisgroup <- rep(NA_character_, times = nrow(results))
     from_group <- grepl(paste0("(", paste0(submod, collapse = "|"), ")\\."), results$matrix)
     thisgroup[from_group] <- gsub(paste0("^.{0,}(", paste0(submod, collapse = "|"), ").{0,}$"), "\\1", results$matrix[from_group])
+    # Default name: group
     thename <- "group"
-    if(inherits(x$expectation, "MxExpectationMixture")){
+    # Alternative names:
+    if(inherits(x$expectation, "MxExpectationMixture") | isTRUE(attr(x, "tidySEM") == "mixture")){
       thename <- "class"
+      if(!inherits(x$expectation, "MxExpectationMixture")) thisgroup[results$matrix %in% c("S", "M")] <- "class1"
     }
+
     existingnames <- sum(gregexpr(thename, paste0(names(results), collapse = ""))[[1]] > 0)
     if(existingnames > 0) thename <- paste0(thename, ".", existingnames, collapse = "")
     results[[thename]] <- thisgroup
@@ -481,6 +522,9 @@ mx_to_lavaan_labels <- function(x){
   these <- which(x$matrix == "Thresholds")
   #out[these] <- paste0("Thresholds.", x$lhs[these], ".ON.", x$rhs[these])
   cat[these] <- "Thresholds"
+  these <- which(x$matrix == "weights")
+  #out[these] <- paste0("Thresholds.", x$lhs[these], ".ON.", x$rhs[these])
+  cat[these] <- "Weights"
   cbind(label = out, Category = cat)
 }
 
