@@ -1,4 +1,3 @@
-library(testthat)
 df <- HolzingerSwineford1939
 names(df)[grepl("^x", names(df))] <- c("vis_1", "vis_2", "vis_3", "tex_1", "tex_2", "tex_3", "spe_1", "spe_2", "spe_3")
 
@@ -6,9 +5,7 @@ mod <- "vis =~ vis_1 + vis_2 + vis_3
 tex =~ tex_1 + tex_2 + tex_3
 spe =~ spe_1 + spe_2 + spe_3"
 
-res1 <- lavaan::sem (mod, data = df)
-parTable(res1)
-
+res1 <- lavaan::sem(mod, data = df, meanstructure = TRUE)
 
 mod_ts <- measurement(tidy_sem(df))
 res2 <- sem(as_lavaan(mod_ts), data = df)
